summaryrefslogtreecommitdiffstats
path: root/sound/usb/line6/pod.c
diff options
context:
space:
mode:
Diffstat (limited to 'sound/usb/line6/pod.c')
-rw-r--r--sound/usb/line6/pod.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sound/usb/line6/pod.c b/sound/usb/line6/pod.c
index 6f4b09982589..7766f5349324 100644
--- a/sound/usb/line6/pod.c
+++ b/sound/usb/line6/pod.c
@@ -1,5 +1,5 @@
/*
* Line6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)
*
@@ -59,7 +59,7 @@ enum {
struct usb_line6_pod {
/**
- Generic Line6 USB data.
+ Generic Line 6 USB data.
*/
struct usb_line6 line6;
@@ -627,5 +627,5 @@ static struct usb_driver pod_driver = {
module_usb_driver(pod_driver);
-MODULE_DESCRIPTION("Line6 POD USB driver");
+MODULE_DESCRIPTION("Line 6 POD USB driver");
MODULE_LICENSE("GPL");
@@ -1,5 +1,5 @@
/*
- * Line6 Linux USB driver - 0.9.1beta
+ * Line 6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)